import { JSXElement, Show, onCleanup, useContext } from "solid-js";
import { ModalContext } from "./Root";
import { LoginForm } from "./RegLogin/Login";
import { RegisterForm } from "./RegLogin/Register";

export function LoginModal(): JSXElement {
  const modal_ctx = useContext(ModalContext);

  if (!modal_ctx) {
    // Handle the case where ModalContext is not available
    return null;
  }

  const closeModal = (): void => {
    modal_ctx.setLoginModalOpen(false);
  };

  // Close the modal when the component is unmounted
  onCleanup(() => {
    modal_ctx.setLoginModalOpen(false);
  });

  return (
    <Show when={modal_ctx.loginModalOpen()}>
      <dialog class="modal modal-open">
        <div class="modal-box">
          <form method="dialog">
            <button
              onclick={closeModal}
              class="btn btn-sm btn-circle btn-ghost absolute right-2 top-2"
            >
              ✕
            </button>
          </form>
          <h3 class="font-bold text-lg mb-2">Welcome!</h3>
          <div class="tabs tabs-lifted">
            <input
              type="radio"
              name="login_tabs"
              class="tab"
              aria-label="Login"
              checked
            />
            <div class="tab-content bg-base-100 border-base-300 rounded-box p-10">
              <LoginForm />
            </div>

            <input
              type="radio"
              name="login_tabs"
              class="tab"
              aria-label="Register"
            />
            <div class="tab-content bg-base-100 border-base-300 rounded-box p-10">
              <RegisterForm />
            </div>
          </div>
        </div>
        <form method="dialog" class="modal-backdrop">
          <button onclick={closeModal}>close</button>
        </form>
      </dialog>
    </Show>
  );
}
