import { JSXElement, createSignal, useContext } from "solid-js";
import { LoginContext, ModalContext } from "../Root";

export function RegisterForm(): JSXElement {
  const modal_ctx = useContext(ModalContext);
  const login_ctx = useContext(LoginContext);
  const [username, setUsername] = createSignal<string>("");
  const [password, setPassword] = createSignal<string>("");
  const [captcha, setCaptcha] = createSignal<string>("");
  const [waiting, setWaiting] = createSignal(false);
  const [error, setError] = createSignal(false);

  async function loginFailed(): Promise<void> {
    setError(true);
    setWaiting(false);
    setTimeout(() => {
      setError(false);
    }, 1000);
  }

  async function regPress(e: Event): Promise<void> {
    e.preventDefault();
    setWaiting(true);
    submitRegistration(username(), password(), captcha()).then((token) => {
      if (token != "") {
        setWaiting(false);
        setError(false);
        login_ctx?.setUsername(username());
        login_ctx?.setToken(token);
        modal_ctx?.setLoginModalOpen(false);
        setUsername("");
        setPassword("");
      } else {
        loginFailed();
      }
    });
  }

  return (
    <form class="form-control space-y-2">
      <input
        type="text"
        placeholder="Username"
        value={username()}
        class="input input-bordered"
        onChange={(e): void => {
          setUsername(e.target.value);
        }}
      />

      <input
        type="password"
        placeholder="Password"
        value={password()}
        class="input input-bordered"
        onChange={(e): void => {
          setPassword(e.target.value);
        }}
      />

      <input
        type="text"
        placeholder="Captcha"
        value={password()}
        class="input input-bordered"
        onChange={(e): void => {
          setCaptcha(e.target.value);
        }}
      />

      <button
        class={"btn btn-primary" + (error() ? " btn-error" : "")}
        onClick={regPress}
      >
        {waiting() ? "Logging in..." : "Login"}
      </button>
    </form>
  );
}

// This function is responsible for sending the login request to the server
// and storing the token in localstorage
export async function submitRegistration(
  username: string,
  password: string,
  captcha: string
): Promise<string> {
  const response = await fetch("/api/register", {
    method: "POST",
    headers: { "Content-Type": "application/json" },
    body: JSON.stringify({ username, password, captcha }),
  });

  if (response.ok) {
    const data = await response.json();
    if (data.token && data.username) {
      localStorage.setItem("token", data.token);
      localStorage.setItem("username", data.username);
      return data.token;
    }
  }
  return "";
}
